The DeePMD Calculator
--------------------

The Deep Potential for Molecular Dynamics (DeePMD) is a package that builds machine-learned interatomic potentials from energy and force-field data. These machine-learned potentials are particularlly powerful when trained on DFT data and then subsequently used to run molecular dynamics simulations.

The code is free and open-source.

## Helpful links

 - [github](https://github.com/deepmodeling/deepmd-kit)
 - [documentation](https://docs.deepmodeling.org/projects/deepmd/en/master/)
 - [paper](https://www.sciencedirect.com/science/article/pii/S0010465518300882)
